@@ -1,8 +1,10 @@
 """Tests for the `capture` module."""
 
+from __future__ import annotations
+
 import pytest
 
-from failprint.capture import Capture, cast_capture
+from failprint._internal.capture import Capture
 
 
 @pytest.mark.parametrize(
@@ -21,12 +23,11 @@ from failprint.capture import Capture, cast_capture
         (None, Capture.BOTH),  # default
     ],
 )
-def test_cast_string(value, expected):
-    """
-    Cast various values in a Capture enumeration value.
+def test_cast_string(value: str | bool | Capture, expected: Capture) -> None:
+    """Cast various values in a Capture enumeration value.
 
     Arguments:
         value: The value to cast.
         expected: The value to expect.
     """
-    assert cast_capture(value) == expected
+    assert Capture.cast(value) == expected
